@@ -470,10 +470,6 @@ panel_run_dialog_response (PanelRunDialog *dialog,
 	case GTK_RESPONSE_CANCEL:
 		gtk_widget_destroy (dialog->run_dialog);
 		break;
-	case GTK_RESPONSE_HELP:
-		panel_show_help (gtk_window_get_screen (GTK_WINDOW (run_dialog)),
-				 "user-guide", "gospanel-23", NULL);
-		break;
 	default:
 		break;
 	}
